@@ -1,5 +1,6 @@
 import click
 import logging
+from importlib import resources
 
 from hexacontroller_sc_server import server
 
@@ -23,7 +24,8 @@ def check_port(port) -> None:
 def retrieve_config_path(roc) -> str:
     match roc:
         case 'ROCv3':
-            config_path = 'regmaps/HGCROC3_I2C_params_regmap.csv'
+            config_path = resources.path('hexacontroller_sc_server.regmaps',
+                                         'HGCROC3_I2C_params_regmap.csv')
         case 'ROCv2':
             config_path = 'regmaps/something else'
         # add all cases when I have all the regmaps
